@@ -92,19 +92,19 @@ def create_ledger_text_file_storage(txn_serializer, hash_serializer, tempdir, in
                               storeContentHash=False,
                               ensureDurability=False)
 
-    return __create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file)
+    return _create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file)
 
 
 def create_ledger_leveldb_storage(txn_serializer, hash_serializer, tempdir, init_genesis_txn_file=None):
     store = KeyValueStorageLeveldbIntKeys(tempdir,
                                           'transactions')
-    return __create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file)
+    return _create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file)
 
 
 def create_ledger_rocksdb_storage(txn_serializer, hash_serializer, tempdir, init_genesis_txn_file=None):
     store = KeyValueStorageRocksdbIntKeys(tempdir,
                                           'transactions')
-    return __create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file)
+    return _create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file)
 
 
 def create_ledger_chunked_file_storage(txn_serializer, hash_serializer, tempdir, init_genesis_txn_file=None):
@@ -126,10 +126,10 @@ def create_ledger_chunked_file_storage(txn_serializer, hash_serializer, tempdir,
                              chunk_creator=chunk_creator,
                              storeContentHash=False,
                              ensureDurability=False)
-    return __create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file)
+    return _create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file)
 
 
-def __create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file=None):
+def _create_ledger(store, txn_serializer, hash_serializer, tempdir, init_genesis_txn_file=None):
     genesis_txn_initiator = GenesisTxnInitiatorFromFile(tempdir,
                                                         init_genesis_txn_file) if init_genesis_txn_file else None
     ledger = Ledger(CompactMerkleTree(hashStore=FileHashStore(dataDir=tempdir)),
