@@ -1,6 +1,7 @@
 from crypto.bls.bls_key_register import BlsKeyRegister
-from plenum.common.constants import BLS_KEY, TXN_TYPE, NODE, ALIAS, DATA
+from plenum.common.constants import BLS_KEY, NODE, ALIAS, DATA
 from plenum.common.tools import lazy_field
+from plenum.common.txn_util import get_payload_data, get_type
 
 
 class BlsKeyRegisterPoolLedger(BlsKeyRegister):
@@ -25,8 +26,8 @@ class BlsKeyRegisterPoolLedger(BlsKeyRegister):
     def _load_keys_for_root(self):
         keys = {}
         for _, txn in self._ledger.getAllTxn():
-            if txn[TXN_TYPE] == NODE:
-                data = txn[DATA]
+            if get_type(txn) == NODE:
+                data = get_payload_data(txn)[DATA]
                 alias = data[ALIAS]
                 blskey = data.get(BLS_KEY)
                 keys[alias] = blskey
