@@ -40,7 +40,7 @@ from plenum.common.constants import REPLY, POOL_LEDGER_TXNS, \
     LEDGER_STATUS, CONSISTENCY_PROOF, CATCHUP_REP, REQACK, REQNACK, REJECT, \
     OP_FIELD_NAME, POOL_LEDGER_ID, LedgerState, MULTI_SIGNATURE, MULTI_SIGNATURE_PARTICIPANTS, \
     MULTI_SIGNATURE_SIGNATURE, MULTI_SIGNATURE_VALUE
-from plenum.common.txn_util import idr_from_req_data
+from plenum.common.txn_util import get_reply_itentifier, get_reply_reqId
 from plenum.common.types import f
 from plenum.common.util import getMaxFailures, rawToFriendly, mostCommonElement
 from plenum.persistence.client_req_rep_store_file import ClientReqRepStoreFile
@@ -132,6 +132,7 @@ class Client(Motor,
             self.ledgerManager.addLedger(
                 POOL_LEDGER_ID,
                 self.ledger,
+                preCatchupStartClbk=self.prePoolLedgerCatchup,
                 postCatchupCompleteClbk=self.postPoolLedgerCaughtUp,
                 postTxnAddedToLedgerClbk=self.postTxnFromCatchupAddedToLedger)
         else:
@@ -227,6 +228,9 @@ class Client(Motor,
     def __repr__(self):
         return self.name
 
+    def prePoolLedgerCatchup(self, **kwargs):
+        self.mode = Mode.discovering
+
     def postPoolLedgerCaughtUp(self):
         self.mode = Mode.discovered
         # For the scenario where client has already connected to nodes reading
@@ -366,8 +370,8 @@ class Client(Motor,
                 self._got_expected(msg, frm)
             elif msg[OP_FIELD_NAME] == REPLY:
                 result = msg[f.RESULT.nm]
-                identifier = idr_from_req_data(msg[f.RESULT.nm])
-                reqId = msg[f.RESULT.nm][f.REQ_ID.nm]
+                identifier = get_reply_itentifier(result)
+                reqId = get_reply_reqId(result)
                 numReplies = self.reqRepStore.addReply(identifier,
                                                        reqId,
                                                        frm,
@@ -450,9 +454,8 @@ class Client(Motor,
         :return: list of request results from all nodes
         """
         return {frm: msg for msg, frm in self.inBox
-                if msg[OP_FIELD_NAME] == REPLY and
-                msg[f.RESULT.nm][f.REQ_ID.nm] == reqId and
-                idr_from_req_data(msg[f.RESULT.nm]) == identifier}
+                if msg[OP_FIELD_NAME] == REPLY and get_reply_reqId(msg[f.RESULT.nm]) == reqId and
+                get_reply_itentifier(msg[f.RESULT.nm]) == identifier}
 
     def hasConsensus(self, identifier: str, reqId: int) -> Optional[Reply]:
         """
@@ -700,8 +703,8 @@ class Client(Motor,
 
     def _got_expected(self, msg, sender):
 
-        def drop(req, register):
-            key = (req.get(f.IDENTIFIER.nm), req.get(f.REQ_ID.nm))
+        def drop(identifier, reqId, register):
+            key = (identifier, reqId)
             if key in register:
                 received = register[key][0]
                 if sender in received:
@@ -710,13 +713,13 @@ class Client(Motor,
                     register.pop(key)
 
         if msg[OP_FIELD_NAME] == REQACK:
-            drop(msg, self.expectingAcksFor)
+            drop(get_reply_itentifier(msg), get_reply_reqId(msg), self.expectingAcksFor)
         elif msg[OP_FIELD_NAME] == REPLY:
-            drop(msg[f.RESULT.nm], self.expectingAcksFor)
-            drop(msg[f.RESULT.nm], self.expectingRepliesFor)
+            drop(get_reply_itentifier(msg[f.RESULT.nm]), get_reply_reqId(msg[f.RESULT.nm]), self.expectingAcksFor)
+            drop(get_reply_itentifier(msg[f.RESULT.nm]), get_reply_reqId(msg[f.RESULT.nm]), self.expectingRepliesFor)
         elif msg[OP_FIELD_NAME] in (REQNACK, REJECT):
-            drop(msg, self.expectingAcksFor)
-            drop(msg, self.expectingRepliesFor)
+            drop(get_reply_itentifier(msg), get_reply_reqId(msg), self.expectingAcksFor)
+            drop(get_reply_itentifier(msg), get_reply_reqId(msg), self.expectingRepliesFor)
         else:
             raise RuntimeError("{} cannot retry {}".format(self, msg))
 
