@@ -82,9 +82,10 @@ class MessageBase(Mapping, MessageValidator):
 
         argsLen = len(args or kwargs)
         assert argsLen <= len(self.schema), \
-            "number of parameters should be less or " \
-            "equal than a number of fields in schema, but it was {}".format(argsLen)
+            "number of parameters should be less than or equal to " \
+            "the number of fields in schema, but it was {}".format(argsLen)
 
+        super().__init__()
         input_as_dict = kwargs if kwargs else self._join_with_schema(args)
 
         self.validate(input_as_dict)
