@@ -4,25 +4,25 @@ from common.serializers.serialization import domain_state_serializer, \
     proof_nodes_serializer, state_roots_serializer
 from ledger.util import F
 from plenum.common.constants import TXN_TYPE, NYM, ROLE, STEWARD, TARGET_NYM, \
-    VERKEY, TXN_TIME, ROOT_HASH, MULTI_SIGNATURE, PROOF_NODES, DATA, STATE_PROOF
+    VERKEY, TXN_TIME, ROOT_HASH, MULTI_SIGNATURE, PROOF_NODES, DATA, \
+    STATE_PROOF
 from plenum.common.exceptions import UnauthorizedClientRequest
 from plenum.common.plenum_protocol_version import PlenumProtocolVersion
 from plenum.common.request import Request
-from plenum.common.txn_util import reqToTxn
+from plenum.common.txn_util import reqToTxn, get_type, get_payload_data, get_seq_no, get_txn_time, get_from
 from plenum.common.types import f
-from plenum.persistence.util import txnsWithSeqNo
-from plenum.server.req_handler import RequestHandler
+from plenum.server.ledger_req_handler import LedgerRequestHandler
 from stp_core.common.log import getlogger
 
 logger = getlogger()
 
 
-class DomainRequestHandler(RequestHandler):
+class DomainRequestHandler(LedgerRequestHandler):
     stateSerializer = domain_state_serializer
     write_types = {NYM, }
 
-    def __init__(self, ledger, state, config, reqProcessors, bls_store):
-        super().__init__(ledger, state)
+    def __init__(self, ledger, state, config, reqProcessors, bls_store, ts_store=None):
+        super().__init__(ledger, state, ts_store=ts_store)
         self.config = config
         self.reqProcessors = reqProcessors
         self.bls_store = bls_store
@@ -47,20 +47,13 @@ class DomainRequestHandler(RequestHandler):
                                                 req.reqId,
                                                 error)
 
-    def _reqToTxn(self, req: Request, cons_time: int):
-        txn = reqToTxn(req, cons_time)
+    def _reqToTxn(self, req: Request):
+        txn = reqToTxn(req)
         for processor in self.reqProcessors:
             res = processor.process(req)
             txn.update(res)
         return txn
 
-    def apply(self, req: Request, cons_time: int):
-        txn = self._reqToTxn(req, cons_time)
-        (start, end), _ = self.ledger.appendTxns(
-            [self.transform_txn_for_ledger(txn)])
-        self.updateState(txnsWithSeqNo(start, end, [txn]))
-        return start, txn
-
     @staticmethod
     def transform_txn_for_ledger(txn):
         """
@@ -75,9 +68,9 @@ class DomainRequestHandler(RequestHandler):
             self._updateStateWithSingleTxn(txn, isCommitted=isCommitted)
 
     def _updateStateWithSingleTxn(self, txn, isCommitted=False):
-        typ = txn.get(TXN_TYPE)
+        typ = get_type(txn)
         if typ == NYM:
-            nym = txn.get(TARGET_NYM)
+            nym = get_payload_data(txn).get(TARGET_NYM)
             self.updateNym(nym, txn, isCommitted=isCommitted)
         else:
             logger.debug(
@@ -91,7 +84,7 @@ class DomainRequestHandler(RequestHandler):
         """
         # THIS SHOULD NOT BE DONE FOR PRODUCTION
         return sum(1 for _, txn in self.ledger.getAllTxn() if
-                   (txn[TXN_TYPE] == NYM) and (txn.get(ROLE) == STEWARD))
+                   (get_type(txn) == NYM) and (get_payload_data(txn).get(ROLE) == STEWARD))
 
     def stewardThresholdExceeded(self, config) -> bool:
         """We allow at most `stewardThreshold` number of  stewards to be added
@@ -101,10 +94,11 @@ class DomainRequestHandler(RequestHandler):
     def updateNym(self, nym, txn, isCommitted=True):
         existingData = self.getNymDetails(self.state, nym,
                                           isCommitted=isCommitted)
+        txn_data = get_payload_data(txn)
         newData = {}
         if not existingData:
             # New nym being added to state, set the TrustAnchor
-            newData[f.IDENTIFIER.nm] = txn.get(f.IDENTIFIER.nm)
+            newData[f.IDENTIFIER.nm] = get_from(txn)
             # New nym being added to state, set the role and verkey to None, this makes
             # the state data always have a value for `role` and `verkey` since we allow
             # clients to omit specifying `role` and `verkey` in the request consider a
@@ -112,12 +106,12 @@ class DomainRequestHandler(RequestHandler):
             newData[ROLE] = None
             newData[VERKEY] = None
 
-        if ROLE in txn:
-            newData[ROLE] = txn[ROLE]
-        if VERKEY in txn:
-            newData[VERKEY] = txn[VERKEY]
-        newData[F.seqNo.name] = txn.get(F.seqNo.name)
-        newData[TXN_TIME] = txn.get(TXN_TIME)
+        if ROLE in txn_data:
+            newData[ROLE] = txn_data[ROLE]
+        if VERKEY in txn_data:
+            newData[VERKEY] = txn_data[VERKEY]
+        newData[F.seqNo.name] = get_seq_no(txn)
+        newData[TXN_TIME] = get_txn_time(txn)
         existingData.update(newData)
         val = self.stateSerializer.serialize(existingData)
         key = self.nym_to_state_key(nym)
@@ -162,31 +156,44 @@ class DomainRequestHandler(RequestHandler):
     def nym_to_state_key(nym: str) -> bytes:
         return sha256(nym.encode()).digest()
 
-    def make_proof(self, path, head_hash=None):
+    def get_value_from_state(self, path, head_hash=None, with_proof=False):
         '''
-        Creates a state proof for the given path in state trie.
-        Returns None if there is no BLS multi-signature for the given state (it can
-        be the case for txns added before multi-signature support).
-
+        Get a value (and proof optionally)for the given path in state trie.
+        Does not return the proof is there is no aggregate signature for it.
         :param path: the path generate a state proof for
+        :param head_hash: the root to create the proof against
+        :param get_value: whether to return the value
         :return: a state proof or None
         '''
         root_hash = head_hash if head_hash else self.state.committedHeadHash
-        proof = self.state.generate_state_proof(key=path,
-                                                root=self.state.get_head_by_hash(root_hash),
-                                                serialize=True)
-        encoded_proof = proof_nodes_serializer.serialize(proof)
         encoded_root_hash = state_roots_serializer.serialize(bytes(root_hash))
 
+        if not with_proof:
+            return self.state.get_for_root_hash(root_hash, path), None
+
         multi_sig = self.bls_store.get(encoded_root_hash)
         if not multi_sig:
-            return None
-
-        return {
-            ROOT_HASH: encoded_root_hash,
-            MULTI_SIGNATURE: multi_sig.as_dict(),
-            PROOF_NODES: encoded_proof
-        }
+            # Just return the value and not proof
+            try:
+                return self.state.get_for_root_hash(path, root_hash), None
+            except KeyError:
+                return None, None
+        else:
+            try:
+                proof, value = self.state.generate_state_proof(key=path,
+                                                               root=self.state.get_head_by_hash(root_hash),
+                                                               serialize=True,
+                                                               get_value=True)
+                value = self.state.get_decoded(value) if value else value
+                encoded_proof = proof_nodes_serializer.serialize(proof)
+                proof = {
+                    ROOT_HASH: encoded_root_hash,
+                    MULTI_SIGNATURE: multi_sig.as_dict(),
+                    PROOF_NODES: encoded_proof
+                }
+                return value, proof
+            except KeyError:
+                return None, None
 
     @staticmethod
     def make_result(request, data, last_seq_no, update_time, proof):
