@@ -1,8 +1,7 @@
 import time
 from datetime import datetime
-from operator import itemgetter
 from statistics import mean
-from typing import Dict, Iterable, Optional, Set
+from typing import Dict, Iterable, Optional
 from typing import List
 from typing import Tuple
 
@@ -37,6 +36,10 @@ class RequestTimeTracker:
             self.timestamp = timestamp
             self.ordered = [False] * instance_count
 
+            # True if request was unordered for too long and
+            # was handled by handlers on master replica
+            self.handled = False
+
         def order(self, instId):
             if 0 <= instId < len(self.ordered):
                 self.ordered[instId] = True
@@ -48,6 +51,10 @@ class RequestTimeTracker:
         def is_ordered(self):
             return self.ordered[0]
 
+        @property
+        def is_handled(self):
+            return self.handled
+
         @property
         def is_ordered_by_all(self):
             return all(self.ordered)
@@ -71,12 +78,23 @@ class RequestTimeTracker:
             del self._requests[key]
         return tto
 
+    def handle(self, identifier, reqId):
+        self._requests[identifier, reqId].handled = True
+
     def reset(self):
         self._requests.clear()
 
     def unordered(self):
         return ((key, req.timestamp) for key, req in self._requests.items() if not req.is_ordered)
 
+    def handled_unordered(self):
+        return ((key, req.timestamp) for key, req in self._requests.items()
+                if not req.is_ordered and req.is_handled)
+
+    def unhandled_unordered(self):
+        return ((key, req.timestamp) for key, req in self._requests.items()
+                if not req.is_ordered and not req.is_handled)
+
     def add_instance(self):
         self.instance_count += 1
 
@@ -97,9 +115,6 @@ class Monitor(HasActionQueue, PluginLoaderHelper):
     monitors the performance of each instance. Throughput of requests and
     latency per client request are measured.
     """
-    WARN_NOT_PARTICIPATING_WINDOW_MINS = 5
-    WARN_NOT_PARTICIPATING_UNORDERED_NUM = 10
-    WARN_NOT_PARTICIPATING_MIN_DIFF_SEC = 3
 
     def __init__(self, name: str, Delta: float, Lambda: float, Omega: float,
                  instances: Instances, nodestack,
@@ -174,6 +189,9 @@ class Monitor(HasActionQueue, PluginLoaderHelper):
         #  value is a tuple of ordering time and latency of a request
         self.latenciesByBackupsInLast = {}
 
+        # attention: handlers will work over unordered request only once
+        self.unordered_requests_handlers = []  # type: List[Callable]
+
         # Monitoring suspicious spikes in cluster throughput
         self.clusterThroughputSpikeMonitorData = {
             'value': 0,
@@ -196,6 +214,8 @@ class Monitor(HasActionQueue, PluginLoaderHelper):
             self.checkPerformance,
             self.config.notifierEventTriggeringConfig['clusterThroughputSpike']['freq'])
 
+        self.startRepeating(self.check_unordered, self.config.UnorderedCheckFreq)
+
         if 'disable_view_change' in self.config.unsafe:
             self.isMasterDegraded = lambda: False
         if 'disable_monitor' in self.config.unsafe:
@@ -289,10 +309,14 @@ class Monitor(HasActionQueue, PluginLoaderHelper):
         durations = {}
         for identifier, reqId in reqIdrs:
             if (identifier, reqId) not in self.requestTracker:
-                logger.debug(
-                    "Got untracked ordered request with identifier {} and reqId {}".
-                    format(identifier, reqId))
+                logger.debug("Got untracked ordered request with identifier {} and reqId {}".
+                             format(identifier, reqId))
                 continue
+            for req, started in self.requestTracker.handled_unordered():
+                if req == (identifier, reqId):
+                    logger.info('Consensus for ReqId: {} was achieved by {}:{} in {} seconds.'
+                                .format(req[1], self.name, instId, now - started))
+                    continue
             duration = self.requestTracker.order(instId, identifier, reqId, now)
             if byMaster:
                 self.masterReqLatencies[(identifier, reqId)] = duration
@@ -335,30 +359,19 @@ class Monitor(HasActionQueue, PluginLoaderHelper):
         Record the time at which request ordering started.
         """
         self.requestTracker.start(identifier, reqId, time.perf_counter())
-        self.warn_has_lot_unordered_requests()
 
-    def warn_has_lot_unordered_requests(self):
-        unordered_started_at = []
+    def check_unordered(self):
         now = time.perf_counter()
-        sorted_by_started_at = sorted(self.requestTracker.unordered(), key=itemgetter(1))
-        for _, started_at in sorted_by_started_at:
-            in_window = (now - started_at) < self.WARN_NOT_PARTICIPATING_WINDOW_MINS * 60
-            if not in_window:
-                continue
-            dt = (started_at - unordered_started_at[-1]) if unordered_started_at else None
-            if dt is None or dt > self.WARN_NOT_PARTICIPATING_MIN_DIFF_SEC:
-                unordered_started_at.append(started_at)
-
-        if len(unordered_started_at) >= self.WARN_NOT_PARTICIPATING_UNORDERED_NUM:
-            logger.warning('It looks like {} does not participate in processing messages '
-                           'because it has {} unordered requests '
-                           'in the last {} minutes (assumed that minimum difference between unordered '
-                           'requests is at least {} seconds)'
-                           .format(self, len(unordered_started_at),
-                                   self.WARN_NOT_PARTICIPATING_WINDOW_MINS,
-                                   self.WARN_NOT_PARTICIPATING_MIN_DIFF_SEC))
-            return True
-        return False
+        new_unordereds = [(req, now - started) for req, started in self.requestTracker.unhandled_unordered()
+                          if now - started > self.config.UnorderedCheckFreq]
+        if len(new_unordereds) == 0:
+            return
+        for handler in self.unordered_requests_handlers:
+            handler(new_unordereds)
+        for unordered in new_unordereds:
+            self.requestTracker.handle(*(unordered[0]))
+            logger.debug('Following requests were not ordered for more than {} seconds: {}'
+                         .format(self.config.UnorderedCheckFreq, unordered[0]))
 
     def isMasterDegraded(self):
         """
@@ -441,8 +454,7 @@ class Monitor(HasActionQueue, PluginLoaderHelper):
                             "threshold".format(MONITORING_PREFIX, self, d))
                 logger.trace(
                     "{}'s master's avg request latency is {} and backup's "
-                    "avg request latency is {} ".
-                    format(self, avgLatM, avgLatB))
+                    "avg request latency is {}".format(self, avgLatM, avgLatB))
                 return True
         logger.trace("{} found difference between master and backups "
                      "avg latencies to be acceptable".format(self))
