@@ -9,8 +9,8 @@ LOG_SIZE = 3 * CHK_FREQ
 
 
 def test_second_checkpoint_after_catchup_can_be_stabilized(
-        chkFreqPatched, looper, txnPoolNodeSet, steward1, sdk_wallet_steward,
-        sdk_wallet_client, sdk_pool_handle, tdir, client_tdir, tconf,
+        chkFreqPatched, looper, txnPoolNodeSet, sdk_wallet_steward,
+        sdk_wallet_client, sdk_pool_handle, tdir, tconf,
         allPluginsPath):
     _, new_node = sdk_add_new_steward_and_node(
         looper, sdk_pool_handle, sdk_wallet_steward,
@@ -23,14 +23,28 @@ def test_second_checkpoint_after_catchup_can_be_stabilized(
     # NYM transaction and the batch with Epsilon NODE transaction.
     # Epsilon got these transactions via catch-up.
 
+    master_replica = new_node.replicas._master_replica
+
+    assert len(master_replica.checkpoints) == 0
+
+    assert len(master_replica.stashedRecvdCheckpoints) == 0
+
+    assert master_replica.h == 2
+    assert master_replica.H == 17
+
+    sdk_send_random_and_check(looper, txnPoolNodeSet,
+                              sdk_pool_handle, sdk_wallet_client, 1)
+
     for replica in new_node.replicas:
-        assert len(replica.checkpoints) == 0
+        assert len(replica.checkpoints) == 1
+
+        assert len(replica.stashedRecvdCheckpoints) == 0
 
         assert replica.h == 2
         assert replica.H == 17
 
     sdk_send_random_and_check(looper, txnPoolNodeSet,
-                              sdk_pool_handle, sdk_wallet_client, 7)
+                              sdk_pool_handle, sdk_wallet_client, 6)
     stabilization_timeout = \
         waits.expectedTransactionExecutionTime(len(txnPoolNodeSet))
     looper.runFor(stabilization_timeout)
@@ -49,6 +63,12 @@ def test_second_checkpoint_after_catchup_can_be_stabilized(
         assert replica.checkpoints[6, 10].digest is None
         assert replica.checkpoints[6, 10].isStable is False
 
+        assert len(replica.stashedRecvdCheckpoints) == 1
+        assert 0 in replica.stashedRecvdCheckpoints
+        assert len(replica.stashedRecvdCheckpoints[0]) == 1
+        assert (1, 5) in replica.stashedRecvdCheckpoints[0]
+        assert len(replica.stashedRecvdCheckpoints[0][(1, 5)]) == 4
+
         assert replica.h == 2
         assert replica.H == 17
 
@@ -65,5 +85,7 @@ def test_second_checkpoint_after_catchup_can_be_stabilized(
         assert replica.checkpoints[6, 10].digest is not None
         assert replica.checkpoints[6, 10].isStable is True
 
+        assert len(replica.stashedRecvdCheckpoints) == 0
+
         assert replica.h == 10
         assert replica.H == 25
