@@ -2,6 +2,7 @@ import pytest
 from plenum.test.conftest import getValueFromModule
 
 from plenum.client.client import Client
+from plenum.test.helper import sdk_json_to_request_object
 from plenum.test.malicious_behaviors_client import makeClientFaulty
 
 
@@ -16,4 +17,5 @@ def passThroughReqAcked1(sent1):
     # Overriding reqAcked1 in conftest.py to do nothing because the client
     # shouldn't see ReqAck msgs from all the nodes, since it only sent REQUESTs
     # to some.
-    return sent1
+    request = sdk_json_to_request_object(sent1[0][0])
+    return request
