@@ -8,7 +8,6 @@ import re
 import warnings
 import json
 from contextlib import ExitStack
-from copy import copy
 from functools import partial
 import time
 from typing import Dict, Any
@@ -19,6 +18,8 @@ from indy.did import create_and_store_my_did
 
 from ledger.genesis_txn.genesis_txn_file_util import create_genesis_txn_init_ledger
 from plenum.bls.bls_crypto_factory import create_default_bls_crypto_factory
+from plenum.common.member.member import Member
+from plenum.common.member.steward import Steward
 from plenum.common.signer_did import DidSigner
 from plenum.common.signer_simple import SimpleSigner
 from plenum.test import waits
@@ -34,7 +35,6 @@ from plenum.test.grouped_load_scheduling import GroupedLoadScheduling
 from plenum.test.node_catchup.helper import ensureClientConnectedToNodesAndPoolLedgerSame
 from plenum.test.pool_transactions.helper import buildPoolClientAndWallet, sdk_add_new_nym
 from stp_core.common.logging.handlers import TestingHandler
-from stp_core.crypto.util import randomSeed
 from stp_core.network.port_dispenser import genHa
 from stp_core.types import HA
 from _pytest.recwarn import WarningsRecorder
@@ -44,18 +44,18 @@ from stp_core.loop.eventually import eventually
 from plenum.common.exceptions import BlowUp
 from stp_core.common.log import getlogger, Logger
 from stp_core.loop.looper import Looper, Prodable
-from plenum.common.constants import TXN_TYPE, DATA, NODE, ALIAS, CLIENT_PORT, \
-    CLIENT_IP, NODE_PORT, NYM, CLIENT_STACK_SUFFIX, PLUGIN_BASE_DIR_PATH, ROLE, \
-    STEWARD, TARGET_NYM, VALIDATOR, SERVICES, NODE_IP, BLS_KEY, VERKEY, TRUSTEE
-from plenum.common.txn_util import getTxnOrderedFields
+from plenum.common.constants import DATA, NODE, ALIAS, CLIENT_PORT, \
+    CLIENT_IP, NYM, CLIENT_STACK_SUFFIX, PLUGIN_BASE_DIR_PATH, ROLE, \
+    STEWARD, VALIDATOR, BLS_KEY, TRUSTEE
+from plenum.common.txn_util import getTxnOrderedFields, get_payload_data, get_type
 from plenum.common.types import PLUGIN_TYPE_STATS_CONSUMER, f
 from plenum.common.util import getNoInstances
 from plenum.server.notifier_plugin_manager import PluginManager
-from plenum.test.helper import randomOperation, \
-    checkReqAck, checkLastClientReqForNode, waitForSufficientRepliesForRequests, \
+from plenum.test.helper import checkLastClientReqForNode, \
     waitForViewChange, requestReturnedToNode, randomText, \
     mockGetInstalledDistributions, mockImportModule, chk_all_funcs, \
-    create_new_test_node
+    create_new_test_node, sdk_json_to_request_object, sdk_send_random_requests, \
+    sdk_get_and_check_replies
 from plenum.test.node_request.node_request_helper import checkPrePrepared, \
     checkPropagated, checkPrepared, checkCommitted
 from plenum.test.plugin.helper import getPluginPath
@@ -64,7 +64,7 @@ from plenum.test.test_node import TestNode, TestNodeSet, Pool, \
     checkNodesConnected, ensureElectionsDone, genNodeReg
 from plenum.common.config_helper import PConfigHelper, PNodeConfigHelper
 
-Logger.setLogLevel(logging.NOTSET)
+Logger.setLogLevel(logging.INFO)
 logger = getlogger()
 
 GENERAL_CONFIG_DIR = 'etc/indy'
@@ -73,8 +73,9 @@ GENERAL_CONFIG_DIR = 'etc/indy'
 def get_data_for_role(pool_txn_data, role):
     name_and_seeds = []
     for txn in pool_txn_data['txns']:
-        if txn.get(ROLE) == role:
-            name = txn[ALIAS]
+        txn_data = get_payload_data(txn)
+        if txn_data.get(ROLE) == role:
+            name = txn_data[ALIAS]
             name_and_seeds.append((name, pool_txn_data['seeds'][name]))
     return name_and_seeds
 
@@ -446,15 +447,6 @@ def stewardAndWallet1(looper, txnPoolNodeSet, poolTxnStewardData,
     client.stop()
 
 
-@pytest.fixture(scope="module")
-def steward1(looper, txnPoolNodeSet, stewardAndWallet1):
-    steward, wallet = stewardAndWallet1
-    looper.add(steward)
-    ensureClientConnectedToNodesAndPoolLedgerSame(looper, steward,
-                                                  *txnPoolNodeSet)
-    return steward
-
-
 @pytest.fixture(scope="module")
 def client1(looper, clientAndWallet1):
     client = clientAndWallet1[0]
@@ -469,46 +461,26 @@ def wallet1(clientAndWallet1):
 
 
 @pytest.fixture(scope="module")
-def request1(wallet1):
-    op = randomOperation()
-    req = wallet1.signOp(op)
-    return req
+def sent1(looper, sdk_pool_handle,
+          sdk_wallet_client):
+    request_couple_json = sdk_send_random_requests(
+        looper, sdk_pool_handle, sdk_wallet_client, 1)
+    return request_couple_json
 
 
 @pytest.fixture(scope="module")
-def sent1(client1, request1):
-    return client1.submitReqs(request1)[0][0]
-
-
-@pytest.fixture(scope="module")
-def reqAcked1(looper, txnPoolNodeSet, client1, sent1, faultyNodes):
+def reqAcked1(looper, txnPoolNodeSet, sent1, faultyNodes):
     numerOfNodes = len(txnPoolNodeSet)
 
+    request = sdk_json_to_request_object(sent1[0][0])
+
     # Wait until request received by all nodes
     propTimeout = waits.expectedClientToPoolRequestDeliveryTime(numerOfNodes)
-    coros = [partial(checkLastClientReqForNode, node, sent1)
+    coros = [partial(checkLastClientReqForNode, node, request)
              for node in txnPoolNodeSet]
-    # looper.run(eventuallyAll(*coros,
-    #                          totalTimeout=propTimeout,
-    #                          acceptableFails=faultyNodes))
     chk_all_funcs(looper, coros, acceptable_fails=faultyNodes,
                   timeout=propTimeout)
-
-    # Wait until sufficient number of acks received
-    coros2 = [
-        partial(
-            checkReqAck,
-            client1,
-            node,
-            sent1.identifier,
-            sent1.reqId) for node in txnPoolNodeSet]
-    ackTimeout = waits.expectedReqAckQuorumTime()
-    # looper.run(eventuallyAll(*coros2,
-    #                          totalTimeout=ackTimeout,
-    #                          acceptableFails=faultyNodes))
-    chk_all_funcs(looper, coros2, acceptable_fails=faultyNodes,
-                  timeout=ackTimeout)
-    return sent1
+    return request
 
 
 @pytest.fixture(scope="module")
@@ -551,7 +523,7 @@ def preprepared1(looper, txnPoolNodeSet, propagated1, faultyNodes):
 
 
 @pytest.fixture(scope="module")
-def prepared1(looper, txnPoolNodeSet, client1, preprepared1, faultyNodes):
+def prepared1(looper, txnPoolNodeSet, preprepared1, faultyNodes):
     checkPrepared(looper,
                   txnPoolNodeSet,
                   preprepared1,
@@ -561,7 +533,7 @@ def prepared1(looper, txnPoolNodeSet, client1, preprepared1, faultyNodes):
 
 
 @pytest.fixture(scope="module")
-def committed1(looper, txnPoolNodeSet, client1, prepared1, faultyNodes):
+def committed1(looper, txnPoolNodeSet, prepared1, faultyNodes):
     checkCommitted(looper,
                    txnPoolNodeSet,
                    prepared1,
@@ -571,14 +543,17 @@ def committed1(looper, txnPoolNodeSet, client1, prepared1, faultyNodes):
 
 
 @pytest.fixture(scope="module")
-def replied1(looper, txnPoolNodeSet, client1, committed1, wallet1, faultyNodes):
+def replied1(looper, txnPoolNodeSet, sdk_wallet_client,
+             committed1, faultyNodes, sent1):
     numOfNodes = len(txnPoolNodeSet)
     numOfInstances = getNoInstances(numOfNodes)
     quorum = numOfInstances * (numOfNodes - faultyNodes)
 
+    _, did = sdk_wallet_client
+
     def checkOrderedCount():
         resp = [requestReturnedToNode(node,
-                                      wallet1.defaultId,
+                                      did,
                                       committed1.reqId,
                                       instId)
                 for node in txnPoolNodeSet for instId in range(numOfInstances)]
@@ -589,7 +564,7 @@ def replied1(looper, txnPoolNodeSet, client1, committed1, wallet1, faultyNodes):
                           retryWait=1,
                           timeout=orderingTimeout))
 
-    waitForSufficientRepliesForRequests(looper, client1, requests=[committed1])
+    sdk_get_and_check_replies(looper, sent1)
     return committed1
 
 
@@ -641,31 +616,28 @@ def poolTxnData(request):
         n_idr = SimpleSigner(seed=data['seeds'][node_name].encode()).identifier
         s_idr = DidSigner(seed=data['seeds'][steward_name].encode())
 
-        data['txns'].append({
-            TXN_TYPE: NYM,
-            ROLE: STEWARD,
-            ALIAS: steward_name,
-            TARGET_NYM: s_idr.identifier,
-            VERKEY: s_idr.verkey,
-        })
-        node_txn = {
-            TXN_TYPE: NODE,
-            f.IDENTIFIER.nm: s_idr.identifier,
-            TARGET_NYM: n_idr,
-            DATA: {
-                ALIAS: node_name,
-                SERVICES: [VALIDATOR],
-                NODE_IP: '127.0.0.1',
-                NODE_PORT: genHa()[1],
-                CLIENT_IP: '127.0.0.1',
-                CLIENT_PORT: genHa()[1],
-            }
-        }
+        data['txns'].append(
+                Member.nym_txn(nym=s_idr.identifier,
+                               verkey=s_idr.verkey,
+                               role=STEWARD,
+                               name=steward_name,
+                               seq_no=i)
+        )
+
+        node_txn = Steward.node_txn(steward_nym=s_idr.identifier,
+                                    node_name=node_name,
+                                    nym=n_idr,
+                                    ip='127.0.0.1',
+                                    node_port=genHa()[1],
+                                    client_port=genHa()[1],
+                                    client_ip='127.0.0.1',
+                                    services=[VALIDATOR],
+                                    seq_no=i)
 
         if i <= nodes_with_bls:
             _, bls_key = create_default_bls_crypto_factory().generate_bls_keys(
                 seed=data['seeds'][node_name])
-            node_txn[DATA][BLS_KEY] = bls_key
+            get_payload_data(node_txn)[DATA][BLS_KEY] = bls_key
             data['nodesWithBls'][node_name] = True
 
         data['txns'].append(node_txn)
@@ -676,13 +648,12 @@ def poolTxnData(request):
         data['seeds'][trustee_name] = trustee_name + '0' * (
                 32 - len(trustee_name))
         t_sgnr = DidSigner(seed=data['seeds'][trustee_name].encode())
-        data['txns'].append({
-            TXN_TYPE: NYM,
-            ROLE: TRUSTEE,
-            ALIAS: trustee_name,
-            TARGET_NYM: t_sgnr.identifier,
-            VERKEY: t_sgnr.verkey
-        })
+        data['txns'].append(
+            Member.nym_txn(nym=t_sgnr.identifier,
+                           verkey=t_sgnr.verkey,
+                           role=TRUSTEE,
+                           name=trustee_name)
+        )
 
     more_data_seeds = \
         {
@@ -694,8 +665,12 @@ def poolTxnData(request):
     more_data_users = []
     for more_name, more_seed in more_data_seeds.items():
         signer = DidSigner(seed=more_seed.encode())
-        more_data_users.append({TXN_TYPE: NYM, ALIAS: more_name, TARGET_NYM: signer.identifier, VERKEY: signer.verkey,
-                                f.IDENTIFIER.nm: "5rArie7XKukPCaEwq5XGQJnM9Fc5aZE3M9HAPVfMU2xC"})
+        more_data_users.append(
+            Member.nym_txn(nym=signer.identifier,
+                           verkey=signer.verkey,
+                           name=more_name,
+                           creator="5rArie7XKukPCaEwq5XGQJnM9Fc5aZE3M9HAPVfMU2xC")
+        )
 
     data['txns'].extend(more_data_users)
     data['seeds'].update(more_data_seeds)
@@ -712,7 +687,7 @@ def tdirWithPoolTxns(config_helper_class, poolTxnData, tdir, tconf):
     ledger = create_genesis_txn_init_ledger(config_helper.genesis_dir, tconf.poolTransactionsFile)
 
     for item in poolTxnData["txns"]:
-        if item.get(TXN_TYPE) == NODE:
+        if get_type(item) == NODE:
             ledger.add(item)
     ledger.stop()
     return config_helper.genesis_dir
@@ -732,7 +707,7 @@ def tdirWithClientPoolTxns(poolTxnData, client_ledger_dir):
     ledger = create_genesis_txn_init_ledger(client_ledger_dir, plenum_config.poolTransactionsFile)
 
     for item in poolTxnData["txns"]:
-        if item.get(TXN_TYPE) == NODE:
+        if get_type(item) == NODE:
             ledger.add(item)
     ledger.stop()
     return client_ledger_dir
@@ -749,7 +724,7 @@ def tdirWithDomainTxns(config_helper_class, poolTxnData, tdir, tconf, domainTxnO
     ledger = create_genesis_txn_init_ledger(config_helper.genesis_dir, tconf.domainTransactionsFile)
 
     for item in poolTxnData["txns"]:
-        if item.get(TXN_TYPE) == NYM:
+        if get_type(item) == NYM:
             ledger.add(item)
     ledger.stop()
     return config_helper.genesis_dir
@@ -871,12 +846,36 @@ def txnPoolNodeSet(node_config_helper_class,
         yield nodes
 
 
+@pytest.fixture(scope="module")
+def txnPoolNodeSetNotStarted(node_config_helper_class,
+                             patchPluginManager,
+                             txnPoolNodesLooper,
+                             tdirWithPoolTxns,
+                             tdirWithDomainTxns,
+                             tdir,
+                             tconf,
+                             poolTxnNodeNames,
+                             allPluginsPath,
+                             tdirWithNodeKeepInited,
+                             testNodeClass,
+                             do_post_node_creation):
+    with ExitStack() as exitStack:
+        nodes = []
+        for nm in poolTxnNodeNames:
+            node = exitStack.enter_context(create_new_test_node(
+                testNodeClass, node_config_helper_class, nm, tconf, tdir,
+                allPluginsPath))
+            do_post_node_creation(node)
+            nodes.append(node)
+        yield nodes
+
+
 @pytest.fixture(scope="module")
 def txnPoolCliNodeReg(poolTxnData):
     cliNodeReg = {}
     for txn in poolTxnData["txns"]:
-        if txn[TXN_TYPE] == NODE:
-            data = txn[DATA]
+        if get_type(txn) == NODE:
+            data = get_payload_data(txn)[DATA]
             cliNodeReg[data[ALIAS] +
                        CLIENT_STACK_SUFFIX] = HA(data[CLIENT_IP], data[CLIENT_PORT])
     return cliNodeReg
@@ -940,17 +939,28 @@ def pluginManagerWithImportedModules(pluginManager, monkeypatch):
 
 
 @pytest.fixture
-def testNode(pluginManager, tdir, tconf, node_config_helper_class):
-    name = randomText(20)
-    nodeReg = genNodeReg(names=[name])
-    ha, cliname, cliha = nodeReg[name]
-    config_helper = node_config_helper_class(name, tconf, chroot=tdir)
-    node = TestNode(name=name, ha=ha, cliname=cliname, cliha=cliha,
-                    nodeRegistry=copy(nodeReg),
-                    config_helper=config_helper,
-                    config=tconf,
-                    primaryDecider=None, pluginPaths=None, seed=randomSeed())
-    node.start(None)
+def testNode(pluginManager,
+             node_config_helper_class,
+             txnPoolNodesLooper,
+             tdirWithPoolTxns,
+             tdirWithDomainTxns,
+             tdir,
+             tconf,
+             allPluginsPath,
+             tdirWithNodeKeepInited,
+             do_post_node_creation,
+             poolTxnNodeNames):
+    node = None
+    for p in txnPoolNodesLooper.prodables:
+        if 'Alpha' == p.name:
+            node = p
+    if not node:
+        node = create_new_test_node(
+            TestNode, node_config_helper_class, 'Alpha', tconf, tdir,
+            None)
+        do_post_node_creation(node)
+        txnPoolNodesLooper.add(node)
+        txnPoolNodesLooper.run(checkNodesConnected([node]))
     yield node
     node.stop()
 
@@ -999,7 +1009,10 @@ def sdk_pool_handle(looper, txnPoolNodeSet, tdirWithPoolTxns, sdk_pool_name):
     pool_handle = looper.loop.run_until_complete(
         _gen_pool_handler(tdirWithPoolTxns, sdk_pool_name))
     yield pool_handle
-    looper.loop.run_until_complete(close_pool_ledger(pool_handle))
+    try:
+        looper.loop.run_until_complete(close_pool_ledger(pool_handle))
+    except Exception as e:
+        logger.debug("Unhandled exception: {}".format(e))
 
 
 async def _gen_wallet_handler(pool_name, wallet_name):
