@@ -3,10 +3,6 @@ from functools import partial
 
 from plenum.common.util import check_if_all_equal_in_list
 from stp_core.common.log import getlogger
-from typing import Iterable
-
-from plenum.common.constants import POOL_LEDGER_ID, DOMAIN_LEDGER_ID, \
-    CONFIG_LEDGER_ID
 from stp_core.loop.eventually import eventually
 from stp_core.types import HA
 from plenum.test.helper import checkLedgerEquality, checkStateEquality, \
