@@ -2,6 +2,7 @@ import json
 
 import pytest
 
+from plenum.common.config_helper import PNodeConfigHelper
 from plenum.test.node_catchup.helper import waitNodeDataInequality, \
     waitNodeDataEquality
 from plenum.test.pool_transactions.helper import \
@@ -14,8 +15,9 @@ from plenum.test.helper import sdk_gen_request, sdk_sign_request_objects, \
 from plenum.common.constants import CONFIG_LEDGER_ID, DATA
 from plenum.test.test_config_req_handler import write_conf_op, \
     TestConfigReqHandler, WRITE_CONF, READ_CONF, read_conf_op
-from plenum.test.test_node import TestNode
+from plenum.test.test_node import TestNode, checkNodesConnected
 from stp_core.loop.eventually import eventually
+from stp_core.types import HA
 
 
 class NewTestNode(TestNode):
@@ -113,6 +115,22 @@ def some_config_txns_done(looper, setup, txnPoolNodeSet, keys,
     return send_some_config_txns(looper, sdk_pool_handle, sdk_wallet_client, keys)
 
 
+def start_stopped_node(stopped_node, looper, tconf,
+                       tdir, allPluginsPath,
+                       delay_instance_change_msgs=True):
+    nodeHa, nodeCHa = HA(*
+                         stopped_node.nodestack.ha), HA(*
+                                                        stopped_node.clientstack.ha)
+    config_helper = PNodeConfigHelper(stopped_node.name, tconf, chroot=tdir)
+    restarted_node = NewTestNode(stopped_node.name,
+                                 config_helper=config_helper,
+                                 config=tconf,
+                                 ha=nodeHa, cliha=nodeCHa,
+                                 pluginPaths=allPluginsPath)
+    looper.add(restarted_node)
+    return restarted_node
+
+
 def test_new_node_catchup_config_ledger(looper, some_config_txns_done,
                                         txnPoolNodeSet, sdk_new_node_caught_up):
     """
@@ -122,26 +140,36 @@ def test_new_node_catchup_config_ledger(looper, some_config_txns_done,
            len(some_config_txns_done)
 
 
-def test_disconnected_node_catchup_config_ledger_txns(looper,
+def test_restarted_node_catches_up_config_ledger_txns(looper,
                                                       some_config_txns_done,
                                                       txnPoolNodeSet,
                                                       sdk_wallet_client,
                                                       sdk_pool_handle,
-                                                      sdk_new_node_caught_up, keys):
+                                                      sdk_new_node_caught_up,
+                                                      keys,
+                                                      tconf,
+                                                      tdir,
+                                                      allPluginsPath):
     """
-    A node gets disconnected, a few config ledger txns happen,
-    the disconnected node comes back up and catches up the config ledger
+    A node is stopped, a few config ledger txns happen,
+    the stopped node is started and catches up the config ledger
     """
     new_node = sdk_new_node_caught_up
     disconnect_node_and_ensure_disconnected(
-        looper, txnPoolNodeSet, new_node, stopNode=False)
+        looper, txnPoolNodeSet, new_node, stopNode=True)
+    looper.removeProdable(new_node)
 
     # Do some config txns; using a fixture as a method, passing some arguments
     # as None as they only make sense for the fixture (pre-requisites)
     send_some_config_txns(looper, sdk_pool_handle, sdk_wallet_client, keys)
 
     # Make sure new node got out of sync
-    waitNodeDataInequality(looper, new_node, *txnPoolNodeSet[:-1])
+    for node in txnPoolNodeSet[:-1]:
+        assert new_node.configLedger.size < node.configLedger.size
 
-    reconnect_node_and_ensure_connected(looper, txnPoolNodeSet, new_node)
-    waitNodeDataEquality(looper, new_node, *txnPoolNodeSet[:-1])
+    restarted_node = start_stopped_node(new_node, looper, tconf, tdir,
+                                        allPluginsPath)
+    txnPoolNodeSet[-1] = restarted_node
+    looper.run(checkNodesConnected(txnPoolNodeSet))
+
+    waitNodeDataEquality(looper, restarted_node, *txnPoolNodeSet[:-1])
