@@ -2,7 +2,7 @@ import pytest
 
 from plenum.test import waits
 from plenum.test.delayers import cqDelay
-from plenum.test.helper import sendReqsToNodesAndVerifySuffReplies
+from plenum.test.helper import sdk_send_random_and_check
 from plenum.test.node_catchup.helper import waitNodeDataEquality
 from plenum.test.node_request.node_request_helper import chk_commits_prepares_recvd
 from plenum.test.test_node import ensureElectionsDone
@@ -28,18 +28,19 @@ def nodes_slow_to_process_catchup_reqs(txnPoolNodeSet):
 
 def testNodeDoesNotParticipateUntilCaughtUp(txnPoolNodeSet,
                                             nodes_slow_to_process_catchup_reqs,
-                                            nodeCreatedAfterSomeTxns):
+                                            sdk_node_created_after_some_txns):
     """
     A new node that joins after some transactions should stash new transactions
     until it has caught up
     :return:
     """
 
-    looper, new_node, client, wallet, newStewardClient, newStewardWallet = \
-        nodeCreatedAfterSomeTxns
+    looper, new_node, sdk_pool_handle, new_steward_wallet_handle = \
+        sdk_node_created_after_some_txns
     txnPoolNodeSet.append(new_node)
     old_nodes = txnPoolNodeSet[:-1]
-    sendReqsToNodesAndVerifySuffReplies(looper, wallet, client, 5)
+    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
+                              new_steward_wallet_handle, 5)
     chk_commits_prepares_recvd(0, old_nodes, new_node)
 
     for node in old_nodes:
@@ -51,7 +52,8 @@ def testNodeDoesNotParticipateUntilCaughtUp(txnPoolNodeSet,
     ensureElectionsDone(looper, txnPoolNodeSet, customTimeout=timeout)
     waitNodeDataEquality(looper, new_node, *old_nodes)
 
-    sendReqsToNodesAndVerifySuffReplies(looper, wallet, client, 2)
+    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
+                              new_steward_wallet_handle, 2)
 
     # Commits and Prepares are received by all old nodes
     with pytest.raises(AssertionError):
