@@ -1,4 +1,6 @@
 from plenum.common.util import compare_3PC_keys
+from plenum.test.checkpoints.conftest import tconf, chkFreqPatched, \
+    reqs_for_checkpoint
 from plenum.test.delayers import pDelay, cDelay, ppDelay
 from plenum.test.node_catchup.test_node_reject_invalid_txn_during_catchup import \
     get_any_non_primary_node
@@ -7,14 +9,11 @@ from plenum.test.helper import sdk_send_random_and_check
 from plenum.test.node_catchup.helper import \
     waitNodeDataEquality, \
     waitNodeDataInequality
-from plenum.test.pool_transactions.helper import \
-    disconnect_node_and_ensure_disconnected, \
-    reconnect_node_and_ensure_connected
 
 from stp_core.loop.eventually import eventually
 
+
 logger = getlogger()
-txnCount = 5
 
 
 def make_master_replica_lag(node):
@@ -41,13 +40,19 @@ def replicas_synced(node):
     assert compare_last_ordered_3pc(node) == 0
 
 
+CHK_FREQ = 5
+LOG_SIZE = 3 * CHK_FREQ
+
+
 def test_node_catchup_causes_no_desync(looper, txnPoolNodeSet, sdk_pool_handle,
-                                       sdk_wallet_client, monkeypatch):
+                                       sdk_wallet_client, monkeypatch,
+                                       chkFreqPatched, reqs_for_checkpoint):
     """
     Checks that transactions received by catchup do not
     break performance monitoring
     """
 
+    max_batch_size = chkFreqPatched.Max3PCBatchSize
     lagging_node = get_any_non_primary_node(txnPoolNodeSet)
     rest_nodes = set(txnPoolNodeSet).difference({lagging_node})
 
@@ -58,28 +63,27 @@ def test_node_catchup_causes_no_desync(looper, txnPoolNodeSet, sdk_pool_handle,
                         lambda *x, **y: None)
 
     # Send some requests and check that all replicas except master executed it
-    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
-                              sdk_wallet_client, 5)
+    sdk_send_random_and_check(looper, txnPoolNodeSet,
+                              sdk_pool_handle, sdk_wallet_client,
+                              reqs_for_checkpoint - max_batch_size)
     waitNodeDataInequality(looper, lagging_node, *rest_nodes)
     looper.run(eventually(backup_replicas_run_forward, lagging_node))
 
-    # Disconnect lagging node, send some more requests and start it back
-    # After start it should fall in a such state that it needs to make catchup
-    disconnect_node_and_ensure_disconnected(looper,
-                                            txnPoolNodeSet,
-                                            lagging_node,
-                                            stopNode=False)
-    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
-                              sdk_wallet_client, 5)
-    reconnect_node_and_ensure_connected(looper, txnPoolNodeSet, lagging_node)
+    assert lagging_node.monitor.isMasterDegraded()
 
+    sdk_send_random_and_check(looper, txnPoolNodeSet,
+                              sdk_pool_handle, sdk_wallet_client,
+                              reqs_for_checkpoint + max_batch_size)
     # Check that catchup done
     waitNodeDataEquality(looper, lagging_node, *rest_nodes)
 
+    lagging_node.reset_delays_and_process_delayeds()
+
     # Send some more requests to ensure that backup and master replicas
     # are in the same state
-    sdk_send_random_and_check(looper, txnPoolNodeSet, sdk_pool_handle,
-                              sdk_wallet_client, 5)
+    sdk_send_random_and_check(looper, txnPoolNodeSet,
+                              sdk_pool_handle, sdk_wallet_client,
+                              reqs_for_checkpoint - max_batch_size)
     looper.run(eventually(replicas_synced, lagging_node))
 
     # Check that master is not considered to be degraded
