@@ -11,38 +11,35 @@ ledger_id = 1
 
 
 @pytest.yield_fixture(scope="function")
-def restarted_pool(txnPoolNodeSet):
+def node_and_ledger_info(txnPoolNodeSet):
     '''
-    Emulate restart of the pool
+    Emulate restart of the node (clean state)
     '''
-    for node in txnPoolNodeSet:
-        node.viewNo = None
-        node.master_replica.last_ordered_3pc = (0, 0)
-        node.view_changer.set_defaults()
-    return txnPoolNodeSet
+    node = txnPoolNodeSet[0]
 
+    node.master_replica.last_ordered_3pc = (0, 0)
+
+    view_changer = node.view_changer
+    view_changer.propagate_primary = True
+    view_changer.view_no = 0
+    view_changer.view_change_in_progress = True
+    view_changer.set_defaults()
 
-@pytest.yield_fixture(scope="function")
-def node_and_ledger_info(restarted_pool):
-    '''
-    Emulate restart of the pool (clean state)
-    '''
-    node = restarted_pool[0]
     ledger_manager = node.ledgerManager
     ledger_manager.last_caught_up_3PC = (0, 0)
 
     ledger_info = ledger_manager.getLedgerInfoByType(ledger_id)
     ledger_info.set_defaults()
-    ledger_info.state = LedgerState.syncing
     ledger_info.canSync = True
 
     ledger_status = node.build_ledger_status(ledger_id)
     assert ledger_status.viewNo is None
+    assert ledger_status.ppSeqNo is None
 
     return node, ledger_manager, ledger_info, ledger_status
 
 
-def test_same_ledger_status_quorum(restarted_pool,
+def test_same_ledger_status_quorum(txnPoolNodeSet,
                                    node_and_ledger_info):
     '''
     Check that we require at least n-f-1 (=4) same LedgerStatus msgs
@@ -52,14 +49,14 @@ def test_same_ledger_status_quorum(restarted_pool,
 
     status_from = set()
     for i in range(3):
-        node_name = restarted_pool[i + 1].name
+        node_name = txnPoolNodeSet[i + 1].name
         ledger_manager.processLedgerStatus(ledger_status, node_name)
         status_from = status_from.union({node_name})
         assert ledger_info.ledgerStatusOk == status_from
         assert ledger_info.canSync is True
-        assert ledger_info.state == LedgerState.syncing
+        assert ledger_info.state == LedgerState.not_synced
 
-    node_name = restarted_pool[4].name
+    node_name = txnPoolNodeSet[4].name
     ledger_manager.processLedgerStatus(ledger_status, node_name)
 
     assert ledger_info.ledgerStatusOk == set()
@@ -67,7 +64,7 @@ def test_same_ledger_status_quorum(restarted_pool,
     assert ledger_info.state == LedgerState.synced
 
 
-def test_same_ledger_status_last_ordered_same_3PC(restarted_pool,
+def test_same_ledger_status_last_ordered_same_3PC(txnPoolNodeSet,
                                                   node_and_ledger_info):
     '''
     Check that last_ordered_3PC is set according to 3PC from LedgerStatus msgs
@@ -79,18 +76,18 @@ def test_same_ledger_status_last_ordered_same_3PC(restarted_pool,
                                       2, 20,
                                       ledger_status_none_3PC.merkleRoot)
 
-    ledger_manager.processLedgerStatus(ledger_status_2_40, restarted_pool[1].name)
-    ledger_manager.processLedgerStatus(ledger_status_2_40, restarted_pool[2].name)
-    ledger_manager.processLedgerStatus(ledger_status_2_40, restarted_pool[3].name)
+    ledger_manager.processLedgerStatus(ledger_status_2_40, txnPoolNodeSet[1].name)
+    ledger_manager.processLedgerStatus(ledger_status_2_40, txnPoolNodeSet[2].name)
+    ledger_manager.processLedgerStatus(ledger_status_2_40, txnPoolNodeSet[3].name)
     assert node.master_last_ordered_3PC == (0, 0)
-    assert ledger_info.state == LedgerState.syncing
+    assert ledger_info.state == LedgerState.not_synced
 
-    ledger_manager.processLedgerStatus(ledger_status_2_40, restarted_pool[4].name)
+    ledger_manager.processLedgerStatus(ledger_status_2_40, txnPoolNodeSet[4].name)
     assert node.master_last_ordered_3PC == (2, 20)
     assert ledger_info.state == LedgerState.synced
 
 
-def test_same_ledger_status_last_ordered_same_None_3PC(restarted_pool,
+def test_same_ledger_status_last_ordered_same_None_3PC(txnPoolNodeSet,
                                                        node_and_ledger_info):
     '''
     Check that last_ordered_3PC is set according to 3PC from LedgerStatus msgs
@@ -98,18 +95,18 @@ def test_same_ledger_status_last_ordered_same_None_3PC(restarted_pool,
     '''
     node, ledger_manager, ledger_info, ledger_status_none_3PC = node_and_ledger_info
 
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[1].name)
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[2].name)
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[3].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[1].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[2].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[3].name)
     assert node.master_last_ordered_3PC == (0, 0)
-    assert ledger_info.state == LedgerState.syncing
+    assert ledger_info.state == LedgerState.not_synced
 
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[4].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[4].name)
     assert node.master_last_ordered_3PC == (0, 0)
     assert ledger_info.state == LedgerState.synced
 
 
-def test_same_ledger_status_last_ordered_one_not_none_3PC_last(restarted_pool,
+def test_same_ledger_status_last_ordered_one_not_none_3PC_last(txnPoolNodeSet,
                                                                node_and_ledger_info):
     '''
     Check that last_ordered_3PC is set according to 3PC from LedgerStatus msgs
@@ -124,18 +121,18 @@ def test_same_ledger_status_last_ordered_one_not_none_3PC_last(restarted_pool,
                                       3, 40,
                                       ledger_status_none_3PC.merkleRoot)
 
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[1].name)
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[2].name)
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[3].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[1].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[2].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[3].name)
     assert node.master_last_ordered_3PC == (0, 0)
-    assert ledger_info.state == LedgerState.syncing
+    assert ledger_info.state == LedgerState.not_synced
 
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[4].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[4].name)
     assert node.master_last_ordered_3PC == (0, 0)
     assert ledger_info.state == LedgerState.synced
 
 
-def test_same_ledger_status_last_ordered_one_not_none_3PC_first(restarted_pool,
+def test_same_ledger_status_last_ordered_one_not_none_3PC_first(txnPoolNodeSet,
                                                                 node_and_ledger_info):
     '''
     Check that last_ordered_3PC is set according to 3PC from LedgerStatus msgs
@@ -150,18 +147,18 @@ def test_same_ledger_status_last_ordered_one_not_none_3PC_first(restarted_pool,
                                       3, 40,
                                       ledger_status_none_3PC.merkleRoot)
 
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[1].name)
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[2].name)
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[3].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[1].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[2].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[3].name)
     assert node.master_last_ordered_3PC == (0, 0)
-    assert ledger_info.state == LedgerState.syncing
+    assert ledger_info.state == LedgerState.not_synced
 
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[4].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[4].name)
     assert node.master_last_ordered_3PC == (0, 0)
     assert ledger_info.state == LedgerState.synced
 
 
-def test_same_ledger_status_last_ordered_not_none_3PC_quorum_with_none(restarted_pool,
+def test_same_ledger_status_last_ordered_not_none_3PC_quorum_with_none(txnPoolNodeSet,
                                                                        node_and_ledger_info):
     '''
     Check that last_ordered_3PC is set according to 3PC from LedgerStatus msgs
@@ -176,18 +173,18 @@ def test_same_ledger_status_last_ordered_not_none_3PC_quorum_with_none(restarted
                                       3, 40,
                                       ledger_status_none_3PC.merkleRoot)
 
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[1].name)
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[2].name)
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[3].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[1].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[2].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[3].name)
     assert node.master_last_ordered_3PC == (0, 0)
-    assert ledger_info.state == LedgerState.syncing
+    assert ledger_info.state == LedgerState.not_synced
 
-    ledger_manager.processLedgerStatus(ledger_status_none_3PC, restarted_pool[4].name)
+    ledger_manager.processLedgerStatus(ledger_status_none_3PC, txnPoolNodeSet[4].name)
     assert node.master_last_ordered_3PC == (3, 40)
     assert ledger_info.state == LedgerState.synced
 
 
-def test_same_ledger_status_last_ordered_not_none_3PC_quorum1(restarted_pool,
+def test_same_ledger_status_last_ordered_not_none_3PC_quorum1(txnPoolNodeSet,
                                                               node_and_ledger_info):
     '''
     Check that last_ordered_3PC is set according to 3PC from LedgerStatus msgs
@@ -207,18 +204,18 @@ def test_same_ledger_status_last_ordered_not_none_3PC_quorum1(restarted_pool,
                                       3, 40,
                                       ledger_status_none_3PC.merkleRoot)
 
-    ledger_manager.processLedgerStatus(ledger_status_1_10, restarted_pool[1].name)
-    ledger_manager.processLedgerStatus(ledger_status_1_10, restarted_pool[2].name)
-    ledger_manager.processLedgerStatus(ledger_status_1_10, restarted_pool[3].name)
+    ledger_manager.processLedgerStatus(ledger_status_1_10, txnPoolNodeSet[1].name)
+    ledger_manager.processLedgerStatus(ledger_status_1_10, txnPoolNodeSet[2].name)
+    ledger_manager.processLedgerStatus(ledger_status_1_10, txnPoolNodeSet[3].name)
     assert node.master_last_ordered_3PC == (0, 0)
-    assert ledger_info.state == LedgerState.syncing
+    assert ledger_info.state == LedgerState.not_synced
 
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[4].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[4].name)
     assert node.master_last_ordered_3PC == (1, 10)
     assert ledger_info.state == LedgerState.synced
 
 
-def test_same_ledger_status_last_ordered_not_none_3PC_quorum2(restarted_pool,
+def test_same_ledger_status_last_ordered_not_none_3PC_quorum2(txnPoolNodeSet,
                                                               node_and_ledger_info):
     '''
     Check that last_ordered_3PC is set according to 3PC from LedgerStatus msgs
@@ -238,18 +235,18 @@ def test_same_ledger_status_last_ordered_not_none_3PC_quorum2(restarted_pool,
                                       3, 40,
                                       ledger_status_none_3PC.merkleRoot)
 
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[1].name)
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[2].name)
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[3].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[1].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[2].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[3].name)
     assert node.master_last_ordered_3PC == (0, 0)
-    assert ledger_info.state == LedgerState.syncing
+    assert ledger_info.state == LedgerState.not_synced
 
-    ledger_manager.processLedgerStatus(ledger_status_1_10, restarted_pool[4].name)
+    ledger_manager.processLedgerStatus(ledger_status_1_10, txnPoolNodeSet[4].name)
     assert node.master_last_ordered_3PC == (3, 40)
     assert ledger_info.state == LedgerState.synced
 
 
-def test_same_ledger_status_last_ordered_not_none_3PC_no_quorum_equal(restarted_pool,
+def test_same_ledger_status_last_ordered_not_none_3PC_no_quorum_equal(txnPoolNodeSet,
                                                                       node_and_ledger_info):
     '''
     Check that last_ordered_3PC is set according to 3PC from LedgerStatus msgs.
@@ -268,12 +265,12 @@ def test_same_ledger_status_last_ordered_not_none_3PC_no_quorum_equal(restarted_
                                       3, 40,
                                       ledger_status_none_3PC.merkleRoot)
 
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[1].name)
-    ledger_manager.processLedgerStatus(ledger_status_3_40, restarted_pool[2].name)
-    ledger_manager.processLedgerStatus(ledger_status_1_10, restarted_pool[3].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[1].name)
+    ledger_manager.processLedgerStatus(ledger_status_3_40, txnPoolNodeSet[2].name)
+    ledger_manager.processLedgerStatus(ledger_status_1_10, txnPoolNodeSet[3].name)
     assert node.master_last_ordered_3PC == (0, 0)
-    assert ledger_info.state == LedgerState.syncing
+    assert ledger_info.state == LedgerState.not_synced
 
-    ledger_manager.processLedgerStatus(ledger_status_1_10, restarted_pool[4].name)
+    ledger_manager.processLedgerStatus(ledger_status_1_10, txnPoolNodeSet[4].name)
     assert node.master_last_ordered_3PC == (0, 0)
     assert ledger_info.state == LedgerState.synced
