@@ -18,3 +18,18 @@ def split_nodes(nodes):
     other_non_primary_nodes = [n for n in nodes if n not in
                                (slow_node, primary_node)]
     return slow_node, other_nodes, primary_node, other_non_primary_nodes
+
+
+def check_pp_out_of_sync(alive_nodes, disconnected_nodes):
+
+    def get_last_pp(node):
+        return node.master_replica.lastPrePrepare
+
+    last_3pc_key_alive = get_last_pp(alive_nodes[0])
+    for node in alive_nodes[1:]:
+        assert get_last_pp(node) == last_3pc_key_alive
+
+    last_3pc_key_diconnected = get_last_pp(disconnected_nodes[0])
+    assert last_3pc_key_diconnected != last_3pc_key_alive
+    for node in disconnected_nodes[1:]:
+        assert get_last_pp(node) == last_3pc_key_diconnected
