@@ -3,6 +3,7 @@ from functools import partial
 import pytest
 import json
 
+from plenum.common.exceptions import PoolLedgerTimeoutException
 from plenum.test.node_request.helper import nodes_by_rank
 from stp_core.common.util import adict
 from plenum.test.helper import check_request_is_not_returned_to_nodes, \
@@ -41,7 +42,7 @@ def test_6_nodes_pool_cannot_reach_quorum_with_2_faulty(afterElection, looper,
                                                         txnPoolNodeSet, prepared1,
                                                         sdk_wallet_client, sdk_pool_handle):
     reqs = sdk_signed_random_requests(looper, sdk_wallet_client, 1)
-    with pytest.raises(TimeoutError):
+    with pytest.raises(PoolLedgerTimeoutException):
         sdk_send_and_check(reqs, looper, txnPoolNodeSet, sdk_pool_handle)
     check_request_is_not_returned_to_nodes(
         txnPoolNodeSet, sdk_json_to_request_object(json.loads(reqs[0])))
