@@ -3,134 +3,55 @@ import json
 from indy.did import create_and_store_my_did
 from indy.ledger import build_node_request, build_nym_request, build_get_txn_request
 from indy.pool import refresh_pool_ledger
-from plenum.test.node_catchup.helper import waitNodeDataEquality, \
-    ensureClientConnectedToNodesAndPoolLedgerSame
-from plenum.test.node_request.helper import sdk_ensure_pool_functional
+from plenum.test.node_catchup.helper import waitNodeDataEquality
 from stp_core.loop.looper import Looper
 from stp_core.types import HA
 from typing import Iterable, Union, Callable
 
-from plenum.client.client import Client
 from plenum.client.wallet import Wallet
-from plenum.common.constants import STEWARD, TXN_TYPE, NYM, ROLE, TARGET_NYM, ALIAS, \
-    NODE_PORT, CLIENT_IP, NODE_IP, DATA, NODE, CLIENT_PORT, VERKEY, SERVICES, \
-    VALIDATOR, BLS_KEY, CLIENT_STACK_SUFFIX, STEWARD_STRING
+from plenum.common.constants import VERKEY, VALIDATOR, STEWARD_STRING
 from plenum.common.keygen_utils import initNodeKeysForBothStacks
 from plenum.common.signer_simple import SimpleSigner
 from plenum.common.signer_did import DidSigner
 from plenum.common.util import randomString, hexToFriendly
-from plenum.test.helper import waitForSufficientRepliesForRequests, \
-    sdk_sign_request_objects, sdk_send_signed_requests, \
-    sdk_json_to_request_object, sdk_get_and_check_replies
+from plenum.test.helper import sdk_sign_request_objects, \
+    sdk_send_signed_requests, sdk_json_to_request_object, \
+    sdk_get_and_check_replies, sdk_sign_request_strings
+from plenum.test.node_request.helper import sdk_ensure_pool_functional
 from plenum.test.test_client import TestClient, genTestClient
 from plenum.test.test_node import TestNode, \
     ensure_node_disconnected, checkNodesConnected
-from stp_core.loop.eventually import eventually
 from stp_core.network.port_dispenser import genHa
 from plenum.common.config_helper import PNodeConfigHelper
+from stp_core.common.log import getlogger
+
+logger = getlogger()
+
+REFRESH_TRY_COUNT = 4
 
 
-def new_client_request(role, name, creatorWallet):
-    wallet = Wallet(name)
-    wallet.addIdentifier()
-    idr = wallet.defaultId
+def new_client_request(role, name, looper, sdk_wallet):
+    wh, did = sdk_wallet
+    seed = randomString(32)
+    (named_did, named_verkey) = looper.loop.run_until_complete(
+        create_and_store_my_did(wh, json.dumps({'seed': seed})))
+    nym_request = looper.loop.run_until_complete(
+        build_nym_request(did, named_did, named_verkey,
+                          name, role))
 
-    op = {
-        TXN_TYPE: NYM,
-        TARGET_NYM: idr,
-        ALIAS: name,
-        VERKEY: wallet.getVerkey(idr)
-    }
-
-    if role:
-        op[ROLE] = role
-
-    return creatorWallet.signOp(op), wallet
+    return sdk_sign_request_strings(looper, sdk_wallet,
+                                    [json.loads(nym_request)])[0]
 
 
-def sendAddNewClient(role, name, creatorClient, creatorWallet):
-    req, wallet = new_client_request(role, name, creatorWallet)
-    creatorClient.submitReqs(req)
-    return req, wallet
-
-
-def addNewClient(role, looper, creatorClient: Client, creatorWallet: Wallet,
-                 name: str):
-    req, wallet = sendAddNewClient(role, name, creatorClient, creatorWallet)
-    waitForSufficientRepliesForRequests(looper, creatorClient,
-                                        requests=[req])
-
-    return wallet
-
-
-def sendAddNewNode(tdir, tconf, newNodeName, stewardClient, stewardWallet,
-                   transformOpFunc=None):
-    sigseed, verkey, bls_key, nodeIp, nodePort, clientIp, clientPort = \
-        prepare_new_node_data(tconf, tdir, newNodeName)
-    return send_new_node_txn(sigseed,
-                             nodeIp, nodePort, clientIp, clientPort,
-                             bls_key,
-                             newNodeName, stewardClient, stewardWallet,
-                             transformOpFunc)
-
-
-def prepare_new_node_data(tconf, tdir,
-                          newNodeName):
+def prepare_new_node_data(tconf, tdir, newNodeName, configClass=PNodeConfigHelper):
     sigseed = randomString(32).encode()
     (nodeIp, nodePort), (clientIp, clientPort) = genHa(2)
-    config_helper = PNodeConfigHelper(newNodeName, tconf, chroot=tdir)
+    config_helper = configClass(newNodeName, tconf, chroot=tdir)
     _, verkey, bls_key = initNodeKeysForBothStacks(newNodeName, config_helper.keys_dir,
                                                    sigseed, override=True)
     return sigseed, verkey, bls_key, nodeIp, nodePort, clientIp, clientPort
 
 
-def send_new_node_txn(sigseed,
-                      nodeIp, nodePort, clientIp, clientPort,
-                      bls_key,
-                      newNodeName, stewardClient, stewardWallet,
-                      transformOpFunc=None):
-    nodeSigner = SimpleSigner(seed=sigseed)
-    op = {
-        TXN_TYPE: NODE,
-        TARGET_NYM: nodeSigner.identifier,
-        DATA: {
-            NODE_IP: nodeIp,
-            NODE_PORT: nodePort,
-            CLIENT_IP: clientIp,
-            CLIENT_PORT: clientPort,
-            ALIAS: newNodeName,
-            SERVICES: [VALIDATOR, ],
-            BLS_KEY: bls_key
-        }
-    }
-    if transformOpFunc is not None:
-        transformOpFunc(op)
-
-    req = stewardWallet.signOp(op)
-    stewardClient.submitReqs(req)
-    return req, \
-           op[DATA].get(NODE_IP), op[DATA].get(NODE_PORT), \
-           op[DATA].get(CLIENT_IP), op[DATA].get(CLIENT_PORT), \
-           sigseed
-
-
-def addNewNode(looper, stewardClient, stewardWallet, newNodeName, tdir, tconf,
-               allPluginsPath=None, autoStart=True, nodeClass=TestNode,
-               transformOpFunc=None, do_post_node_creation: Callable = None):
-    nodeClass = nodeClass or TestNode
-    req, nodeIp, nodePort, clientIp, clientPort, sigseed \
-        = sendAddNewNode(tdir, tconf, newNodeName, stewardClient, stewardWallet,
-                         transformOpFunc)
-    waitForSufficientRepliesForRequests(looper, stewardClient,
-                                        requests=[req])
-
-    return create_and_start_new_node(looper, newNodeName, tdir, sigseed,
-                                     (nodeIp, nodePort), (clientIp, clientPort),
-                                     tconf, autoStart, allPluginsPath,
-                                     nodeClass,
-                                     do_post_node_creation=do_post_node_creation)
-
-
 def start_not_added_node(looper,
                          tdir, tconf, allPluginsPath,
                          newNodeName):
@@ -153,32 +74,33 @@ def add_started_node(looper,
                      node_ha,
                      client_ha,
                      txnPoolNodeSet,
-                     client_tdir,
-                     stewardClient, stewardWallet,
-                     sigseed,
+                     sdk_pool_handle,
+                     sdk_wallet_steward,
                      bls_key):
     '''
     Adds already created node to the pool,
     that is sends NODE txn.
     Makes sure that node is actually added and connected to all otehr nodes.
     '''
-    newSteward, newStewardWallet = addNewSteward(looper, client_tdir,
-                                                 stewardClient, stewardWallet,
-                                                 "Steward" + new_node.name,
-                                                 clientClass=TestClient)
+    new_steward_wallet_handle = sdk_add_new_nym(looper, sdk_pool_handle,
+                                                sdk_wallet_steward,
+                                                "Steward" + new_node.name,
+                                                role=STEWARD_STRING)
     node_name = new_node.name
-    send_new_node_txn(sigseed,
-                      node_ha[0],
-                      node_ha[1],
-                      client_ha[0],
-                      client_ha[1],
-                      bls_key,
-                      node_name,
-                      newSteward, newStewardWallet)
+    node_dest = hexToFriendly(new_node.nodestack.verhex)
+    sdk_send_update_node(looper, new_steward_wallet_handle,
+                         sdk_pool_handle, node_dest, node_name,
+                         node_ha[0], node_ha[1],
+                         client_ha[0], client_ha[1],
+                         services=[VALIDATOR],
+                         bls_key=bls_key)
 
     txnPoolNodeSet.append(new_node)
     looper.run(checkNodesConnected(txnPoolNodeSet))
-    ensureClientConnectedToNodesAndPoolLedgerSame(looper, newSteward, *txnPoolNodeSet)
+    sdk_pool_refresh(looper, sdk_pool_handle)
+    sdk_ensure_pool_functional(looper, txnPoolNodeSet,
+                               sdk_wallet_steward,
+                               sdk_pool_handle)
 
     waitNodeDataEquality(looper, new_node, *txnPoolNodeSet[:-1])
 
@@ -194,14 +116,16 @@ def create_and_start_new_node(
         auto_start,
         plugin_path,
         nodeClass,
-        do_post_node_creation: Callable = None):
+        do_post_node_creation: Callable = None,
+        configClass=PNodeConfigHelper):
     node = new_node(node_name=node_name,
                     tdir=tdir,
                     node_ha=node_ha,
                     client_ha=client_ha,
                     tconf=tconf,
                     plugin_path=plugin_path,
-                    nodeClass=nodeClass)
+                    nodeClass=nodeClass,
+                    configClass=configClass)
     if do_post_node_creation:
         do_post_node_creation(node)
     if auto_start:
@@ -216,8 +140,9 @@ def new_node(
         client_ha,
         tconf,
         plugin_path,
-        nodeClass):
-    config_helper = PNodeConfigHelper(node_name, tconf, chroot=tdir)
+        nodeClass,
+        configClass=PNodeConfigHelper):
+    config_helper = configClass(node_name, tconf, chroot=tdir)
     node = nodeClass(node_name,
                      config_helper=config_helper,
                      config=tconf,
@@ -226,45 +151,6 @@ def new_node(
     return node
 
 
-def addNewSteward(looper, client_tdir,
-                  creatorClient, creatorWallet, stewardName,
-                  clientClass=TestClient):
-    clientClass = clientClass or TestClient
-    newStewardWallet = addNewClient(STEWARD, looper, creatorClient,
-                                    creatorWallet, stewardName)
-    newSteward = clientClass(name=stewardName,
-                             nodeReg=None, ha=genHa(),
-                             basedirpath=client_tdir)
-
-    looper.add(newSteward)
-    looper.run(newSteward.ensureConnectedToNodes())
-    return newSteward, newStewardWallet
-
-
-def addNewStewardAndNode(looper, creatorClient, creatorWallet, stewardName,
-                         newNodeName, tdir, client_tdir, tconf, allPluginsPath=None,
-                         autoStart=True, nodeClass=TestNode,
-                         clientClass=TestClient, transformNodeOpFunc=None,
-                         do_post_node_creation: Callable = None):
-    newSteward, newStewardWallet = addNewSteward(looper, client_tdir, creatorClient,
-                                                 creatorWallet, stewardName,
-                                                 clientClass=clientClass)
-
-    newNode = addNewNode(
-        looper,
-        newSteward,
-        newStewardWallet,
-        newNodeName,
-        tdir,
-        tconf,
-        allPluginsPath,
-        autoStart=autoStart,
-        nodeClass=nodeClass,
-        transformOpFunc=transformNodeOpFunc,
-        do_post_node_creation=do_post_node_creation)
-    return newSteward, newStewardWallet, newNode
-
-
 def sdk_add_new_steward_and_node(looper,
                                  sdk_pool_handle,
                                  sdk_wallet_steward,
@@ -283,7 +169,7 @@ def sdk_add_new_steward_and_node(looper,
                                                 sdk_wallet_steward,
                                                 alias=new_steward_name,
                                                 role=STEWARD_STRING)
-    newNode = sdk_add_new_node(
+    new_node = sdk_add_new_node(
         looper,
         sdk_pool_handle,
         new_steward_wallet_handle,
@@ -293,22 +179,23 @@ def sdk_add_new_steward_and_node(looper,
         allPluginsPath,
         autoStart=autoStart,
         nodeClass=nodeClass,
-        transformOpFunc=transformNodeOpFunc,
         do_post_node_creation=do_post_node_creation,
         services=services)
-    return new_steward_wallet_handle, newNode
+    return new_steward_wallet_handle, new_node
 
 
 def sdk_add_new_nym(looper, sdk_pool_handle, creators_wallet,
-                    alias=None, role=None, seed=None):
+                    alias=None, role=None, seed=None,
+                    dest=None, verkey=None,skipverkey=False):
     seed = seed or randomString(32)
+    alias = alias or randomString(5)
     wh, _ = creators_wallet
 
     # filling nym request and getting steward did
     # if role == None, we are adding client
     nym_request, new_did = looper.loop.run_until_complete(
         prepare_nym_request(creators_wallet, seed,
-                            alias, role))
+                            alias, role, dest, verkey, skipverkey))
 
     # sending request using 'sdk_' functions
     request_couple = sdk_sign_and_send_prepared_request(looper, creators_wallet,
@@ -325,7 +212,7 @@ def sdk_add_new_node(looper,
                      new_node_name,
                      tdir, tconf,
                      allPluginsPath=None, autoStart=True, nodeClass=TestNode,
-                     transformOpFunc=None, do_post_node_creation: Callable = None,
+                     do_post_node_creation: Callable = None,
                      services=[VALIDATOR]):
     nodeClass = nodeClass or TestNode
     sigseed, verkey, bls_key, nodeIp, nodePort, clientIp, clientPort = \
@@ -355,16 +242,22 @@ def sdk_add_new_node(looper,
                                      (nodeIp, nodePort), (clientIp, clientPort),
                                      tconf, autoStart, allPluginsPath,
                                      nodeClass,
-                                     do_post_node_creation=do_post_node_creation)
+                                     do_post_node_creation=do_post_node_creation,
+                                     configClass=PNodeConfigHelper)
 
 
-async def prepare_nym_request(wallet, named_seed, alias, role):
+async def prepare_schema_request(wallet, named_seed, alias, role):
+    pass
+
+
+async def prepare_nym_request(wallet, named_seed, alias,
+                              role, dest=None, verkey=None, skipverkey=False):
     wh, submitter_did = wallet
-    (named_did, named_verkey) = await create_and_store_my_did(wh,
-                                                              json.dumps({
-                                                                  'seed': named_seed,
-                                                                  'cid': True})
-                                                              )
+    (named_did, named_verkey) = \
+        await create_and_store_my_did(wh, json.dumps({'seed': named_seed}))
+    named_did = dest or named_did
+    named_verkey = verkey or named_verkey
+    named_verkey = None if skipverkey else named_verkey
     nym_request = await build_nym_request(submitter_did, named_did, named_verkey,
                                           alias, role)
     return nym_request, named_did
@@ -409,19 +302,6 @@ def sdk_sign_and_send_prepared_request(looper, sdk_wallet, sdk_pool_handle, stri
     return request_couple
 
 
-def sendUpdateNode(stewardClient, stewardWallet, node, node_data):
-    nodeNym = hexToFriendly(node.nodestack.verhex)
-    op = {
-        TXN_TYPE: NODE,
-        TARGET_NYM: nodeNym,
-        DATA: node_data,
-    }
-
-    req = stewardWallet.signOp(op)
-    stewardClient.submitReqs(req)
-    return req
-
-
 def sdk_send_update_node(looper, sdk_submitter_wallet,
                          sdk_pool_handle,
                          destination, alias,
@@ -452,12 +332,6 @@ def sdk_send_update_node(looper, sdk_submitter_wallet,
     return reply
 
 
-def updateNodeData(looper, stewardClient, stewardWallet, node, node_data):
-    req = sendUpdateNode(stewardClient, stewardWallet, node, node_data)
-    waitForSufficientRepliesForRequests(looper, stewardClient,
-                                        requests=[req])
-
-
 def sdk_pool_refresh(looper, sdk_pool_handle):
     looper.loop.run_until_complete(
         refresh_pool_ledger(sdk_pool_handle))
@@ -510,31 +384,6 @@ def update_node_data_and_reconnect(looper, txnPoolNodeSet,
     return restartedNode
 
 
-def changeNodeKeys(looper, stewardClient, stewardWallet, node, verkey):
-    nodeNym = hexToFriendly(node.nodestack.verhex)
-
-    op = {
-        TXN_TYPE: NODE,
-        TARGET_NYM: nodeNym,
-        VERKEY: verkey,
-        DATA: {
-            ALIAS: node.name
-        }
-    }
-    req = stewardWallet.signOp(op)
-    stewardClient.submitReqs(req)
-
-    waitForSufficientRepliesForRequests(looper, stewardClient,
-                                        requests=[req])
-
-    node.nodestack.clearLocalRoleKeep()
-    node.nodestack.clearRemoteRoleKeeps()
-    node.nodestack.clearAllDir()
-    node.clientstack.clearLocalRoleKeep()
-    node.clientstack.clearRemoteRoleKeeps()
-    node.clientstack.clearAllDir()
-
-
 def sdk_change_node_keys(looper, node, sdk_wallet_steward, sdk_pool_handle, verkey):
     _, steward_did = sdk_wallet_steward
     node_dest = hexToFriendly(node.nodestack.verhex)
@@ -559,37 +408,24 @@ def sdk_change_node_keys(looper, node, sdk_wallet_steward, sdk_pool_handle, verk
     node.clientstack.clearAllDir()
 
 
-def suspendNode(looper, stewardClient, stewardWallet, nodeNym, nodeName):
-    op = {
-        TXN_TYPE: NODE,
-        TARGET_NYM: nodeNym,
-        DATA: {
-            SERVICES: [],
-            ALIAS: nodeName
-        }
-    }
-    req = stewardWallet.signOp(op)
-    stewardClient.submitReqs(req)
-
-    waitForSufficientRepliesForRequests(looper, stewardClient,
-                                        requests=[req])
+def demote_node(looper, steward_wallet, sdk_pool_handle,
+                node):
+    node_nym = hexToFriendly(node.nodestack.verhex)
+    sdk_send_update_node(looper, steward_wallet,
+                         sdk_pool_handle, node_nym, node.name,
+                         None, None,
+                         None, None,
+                         services=[])
 
 
-def cancelNodeSuspension(looper, stewardClient, stewardWallet, nodeNym,
-                         nodeName):
-    op = {
-        TXN_TYPE: NODE,
-        TARGET_NYM: nodeNym,
-        DATA: {
-            SERVICES: [VALIDATOR],
-            ALIAS: nodeName
-        }
-    }
-
-    req = stewardWallet.signOp(op)
-    stewardClient.submitReqs(req)
-    waitForSufficientRepliesForRequests(looper, stewardClient,
-                                        requests=[req])
+def promote_node(looper, steward_wallet, sdk_pool_handle,
+                 node):
+    node_nym = hexToFriendly(node.nodestack.verhex)
+    sdk_send_update_node(looper, steward_wallet,
+                         sdk_pool_handle, node_nym, node.name,
+                         None, None,
+                         None, None,
+                         services=[VALIDATOR])
 
 
 def buildPoolClientAndWallet(clientData, tempDir, clientClass=None, walletClass=None):
@@ -604,16 +440,6 @@ def buildPoolClientAndWallet(clientData, tempDir, clientClass=None, walletClass=
     return client, w
 
 
-def new_client(looper, poolTxnClientData, txnPoolNodeSet, client_tdir):
-    client, wallet = buildPoolClientAndWallet(poolTxnClientData,
-                                              client_tdir)
-    looper.add(client)
-    looper.run(client.ensureConnectedToNodes())
-    ensureClientConnectedToNodesAndPoolLedgerSame(looper, client,
-                                                  *txnPoolNodeSet)
-    return client, wallet
-
-
 def disconnectPoolNode(poolNodes: Iterable,
                        disconnect: Union[str, TestNode],
                        stopNode=True):
@@ -697,30 +523,6 @@ def reconnect_node_and_ensure_connected(looper: Looper,
     looper.run(checkNodesConnected(poolNodes, customTimeout=timeout))
 
 
-def add_2_nodes(looper, existing_nodes, steward, steward_wallet,
-                tdir, client_tdir, tconf, all_plugins_path, names=None):
-    assert names is None or (isinstance(names, list) and len(names) == 2)
-    names = names or ("Zeta", "Eta")
-    new_nodes = []
-    for node_name in names:
-        new_steward_name = "testClientSteward" + randomString(3)
-        new_steward, new_steward_wallet, new_node = addNewStewardAndNode(looper,
-                                                                         steward,
-                                                                         steward_wallet,
-                                                                         new_steward_name,
-                                                                         node_name,
-                                                                         tdir,
-                                                                         client_tdir,
-                                                                         tconf,
-                                                                         all_plugins_path)
-        existing_nodes.append(new_node)
-        looper.run(checkNodesConnected(existing_nodes))
-        waitNodeDataEquality(looper, new_node, *existing_nodes[:-1])
-        new_nodes.append(new_node)
-
-    return new_nodes
-
-
 def sdk_add_2_nodes(looper, txnPoolNodeSet,
                     sdk_pool_handle, sdk_wallet_steward,
                     tdir, tconf, allPluginsPath):
