@@ -7,6 +7,7 @@ from random import randint
 from plenum.common.constants import INVALID_LEDGER_ID, \
     INVALID_SEQ_NO, DATA
 from plenum.common.exceptions import RequestNackedException
+from plenum.common.txn_util import get_seq_no
 from plenum.test.pool_transactions.helper import \
     sdk_sign_and_send_prepared_request, prepare_nym_request, \
     sdk_build_get_txn_request
@@ -117,7 +118,7 @@ def test_get_txn_response_as_expected(looper, txnPoolNodeSet,
 
     result1 = sdk_get_and_check_replies(looper,
                                         [request_couple])[0][1]['result']
-    seqNo = result1['seqNo']
+    seqNo = get_seq_no(result1)
 
     _, steward_did = sdk_wallet_steward
     request = sdk_build_get_txn_request(looper, steward_did, seqNo)
