@@ -1,9 +1,6 @@
-from plenum.common.constants import ALIAS, SERVICES
-
 from plenum.test.helper import sdk_send_random_and_check, waitForViewChange
 from plenum.test.node_catchup.helper import ensure_all_nodes_have_same_data
-from plenum.test.pool_transactions.helper import updateNodeData, \
-    buildPoolClientAndWallet
+from plenum.test.pool_transactions.helper import demote_node
 from plenum.test.view_change.helper import ensure_view_change_by_primary_restart
 from stp_core.common.log import getlogger
 
@@ -13,25 +10,12 @@ logger = getlogger()
 def demote_primary_node(looper,
                         initial_pool_of_nodes,
                         pool_of_nodes,
-                        poolTxnStewardNames,
-                        poolTxnData,
-                        tdirWithClientPoolTxns):
+                        sdk_pool_handle,
+                        sdk_wallet_stewards):
     demoted_node = [node for node in pool_of_nodes if node.has_master_primary][0]
     indx = initial_pool_of_nodes.index(demoted_node)
-    steward_name = poolTxnStewardNames[indx]
-    stewards_seed = poolTxnData["seeds"][steward_name].encode()
-
-    stewardClient, stewardWallet = buildPoolClientAndWallet(
-        (steward_name, stewards_seed), tdirWithClientPoolTxns)
-    looper.add(stewardClient)
-    looper.run(stewardClient.ensureConnectedToNodes())
-
-    node_data = {
-        ALIAS: demoted_node.name,
-        SERVICES: []
-    }
-    updateNodeData(looper, stewardClient,
-                   stewardWallet, demoted_node, node_data)
+    demote_node(looper, sdk_wallet_stewards[indx],
+                sdk_pool_handle, demoted_node)
     pool_of_nodes = list(set(pool_of_nodes) - {demoted_node})
 
     return pool_of_nodes
@@ -41,9 +25,7 @@ def test_restart_primaries_then_demote(
         looper, txnPoolNodeSet,
         tconf, tdir, allPluginsPath,
         sdk_pool_handle, sdk_wallet_steward,
-        poolTxnStewardNames,
-        poolTxnData,
-        tdirWithClientPoolTxns):
+        sdk_wallet_stewards):
     """
     """
     logger.info("1. Restart Node1")
@@ -75,9 +57,8 @@ def test_restart_primaries_then_demote(
     pool_of_nodes = demote_primary_node(looper,
                                         txnPoolNodeSet,
                                         pool_of_nodes,
-                                        poolTxnStewardNames,
-                                        poolTxnData,
-                                        tdirWithClientPoolTxns)
+                                        sdk_pool_handle,
+                                        sdk_wallet_stewards)
 
     # make sure view changed
     waitForViewChange(looper, pool_of_nodes, expectedViewNo=3)
