@@ -10,12 +10,13 @@ whitelist = ['found legacy entry', "doesn't match", 'reconciling nodeReg',
              'conflicting address', 'unable to send message',
              'got error while verifying message']
 
+TestRunningTimeLimitSec = 200
 
 @pytest.mark.skipif('sys.platform == "win32"', reason='SOV-330')
-@pytest.mark.skip(reason='IS-626')
 def testChangeNodeHaForNonPrimary(looper, txnPoolNodeSet, tdirWithClientPoolTxns,
                                   poolTxnData, poolTxnStewardNames, tconf, tdir,
-                                  sdk_pool_handle, sdk_wallet_stewards):
+                                  sdk_pool_handle, sdk_wallet_stewards,
+                                  sdk_wallet_client):
     changeNodeHa(looper,
                  txnPoolNodeSet,
                  tdirWithClientPoolTxns,
@@ -23,4 +24,5 @@ def testChangeNodeHaForNonPrimary(looper, txnPoolNodeSet, tdirWithClientPoolTxns
                  shouldBePrimary=False,
                  tdir=tdir,
                  sdk_pool_handle=sdk_pool_handle,
-                 sdk_wallet_stewards=sdk_wallet_stewards)
+                 sdk_wallet_stewards=sdk_wallet_stewards,
+                 sdk_wallet_client=sdk_wallet_client)
