@@ -11,11 +11,13 @@ whitelist = ['found legacy entry', "doesn't match", 'reconciling nodeReg',
              'conflicting address', 'unable to send message',
              'got error while verifying message']
 
+TestRunningTimeLimitSec = 200
 
 @pytest.mark.skipif('sys.platform == "win32"', reason='SOV-330')
 def testChangeNodeHaForPrimary(looper, txnPoolNodeSet, tdirWithClientPoolTxns,
                                poolTxnData, poolTxnStewardNames, tconf, tdir,
-                               sdk_pool_handle, sdk_wallet_stewards):
+                               sdk_pool_handle, sdk_wallet_stewards,
+                               sdk_wallet_client):
     changeNodeHa(looper,
                  txnPoolNodeSet,
                  tdirWithClientPoolTxns,
@@ -23,4 +25,5 @@ def testChangeNodeHaForPrimary(looper, txnPoolNodeSet, tdirWithClientPoolTxns,
                  shouldBePrimary=True,
                  tdir=tdir,
                  sdk_pool_handle=sdk_pool_handle,
-                 sdk_wallet_stewards=sdk_wallet_stewards)
+                 sdk_wallet_stewards=sdk_wallet_stewards,
+                 sdk_wallet_client=sdk_wallet_client)
