@@ -1,12 +1,15 @@
+import json
+
 import pytest
 
+from indy.did import key_for_did
 from plenum.common.constants import TXN_TYPE, DATA, GET_TXN, DOMAIN_LEDGER_ID
 from plenum.common.exceptions import NoAuthenticatorFound
 from plenum.common.types import f
 from plenum.common.util import randomString
 from plenum.server.client_authn import SimpleAuthNr, CoreAuthNr
 from plenum.server.req_authenticator import ReqAuthenticator
-from plenum.test.plugin.helper import submitOp
+from plenum.test.helper import sdk_sign_and_submit_op
 from plenum.test.pool_transactions.helper import new_client_request
 
 
@@ -38,7 +41,9 @@ def test_authenticator_registration(pre_reqs, registration):
     assert req_authnr.get_authnr_by_type(CoreAuthNr) == core_authnr
 
 
-def test_authentication(pre_reqs, registration, client1, wallet1):
+def test_authentication(looper, pre_reqs, registration,
+                        sdk_wallet_client,
+                        sdk_pool_handle):
     _, core_authnr, req_authnr = pre_reqs
 
     # Remove simple_authnr
@@ -51,9 +56,10 @@ def test_authentication(pre_reqs, registration, client1, wallet1):
         DATA: 1
     }
     # Just creating the request
-    req = submitOp(wallet1, client1, op)
+    req = sdk_sign_and_submit_op(looper, sdk_pool_handle,
+                                 sdk_wallet_client, op)
     with pytest.raises(NoAuthenticatorFound):
-        req_authnr.authenticate(req.as_dict)
+        req_authnr.authenticate(req[0])
 
     # Empty set for query txn type
     op = {
@@ -62,11 +68,13 @@ def test_authentication(pre_reqs, registration, client1, wallet1):
         DATA: 1
     }
     # Just creating the request
-    req = submitOp(wallet1, client1, op)
-    assert set() == req_authnr.authenticate(req.as_dict)
+    req = sdk_sign_and_submit_op(looper, sdk_pool_handle,
+                                 sdk_wallet_client, op)
+    assert set() == req_authnr.authenticate(req[0])
 
     # identifier for write type
-    req, new_wallet = new_client_request(None, randomString(), wallet1)
-    core_authnr.addIdr(wallet1.defaultId,
-                       wallet1.getVerkey(wallet1.defaultId))
-    assert req_authnr.authenticate(req.as_dict) == {wallet1.defaultId, }
+    wh, did = sdk_wallet_client
+    req = new_client_request(None, randomString(), looper, sdk_wallet_client)
+    core_authnr.addIdr(did,
+                       looper.loop.run_until_complete(key_for_did(sdk_pool_handle, wh, did)))
+    assert req_authnr.authenticate(json.loads(req)) == {did, }
