@@ -17,14 +17,15 @@ class IntegerComparator(rocksdb.IComparator):
 
 
 class KeyValueStorageRocksdbIntKeys(KeyValueStorageRocksdb):
-    def __init__(self, db_dir, db_name, open=True):
-        super().__init__(db_dir, db_name, open)
+    def __init__(self, db_dir, db_name, open=True, read_only=False):
+        super().__init__(db_dir, db_name, open, read_only)
+        self._read_only = read_only
 
     def open(self):
         opts = rocksdb.Options()
         opts.create_if_missing = True
         opts.comparator = IntegerComparator()
-        self._db = rocksdb.DB(self._db_path, opts)
+        self._db = rocksdb.DB(self._db_path, opts, read_only=self._read_only)
 
     def get_equal_or_prev(self, key):
         # return value can be:
@@ -40,3 +41,12 @@ class KeyValueStorageRocksdbIntKeys(KeyValueStorageRocksdb):
         except StopIteration:
             value = None
         return value
+
+    def get_last_key(self):
+        itr = self._db.iterkeys()
+        itr.seek_to_last()
+        try:
+            key = next(itr)
+        except StopIteration:
+            key = None
+        return key
