@@ -71,6 +71,8 @@ class KITZStack(SimpleZStack, KITNetworkInterface):
         exclude = exclude or {}
         for name, remote in self.remotes.items():
             if name in exclude or remote.isConnected:
+                if name in self._retry_connect:
+                    self._retry_connect.pop(name, None)
                 continue
 
             if name not in self._retry_connect:
